Crate rppal_w_frontend

RPPAL provides access to the Raspberry Pi’s GPIO, I2C, PWM, SPI and UART peripherals through a user-friendly interface. In addition to peripheral access, RPPAL also offers support for USB to serial adapters. The library can be used in conjunction with a variety of platform-agnostic drivers through its embedded-hal trait implementations by enabling the optional hal feature.

RPPAL requires Raspbian or any similar, recent, Linux distribution. Both gnu and musl libc targets are supported. The library is compatible with the Raspberry Pi A, A+, B, B+, 2B, 3A+, 3B, 3B+, 4B, CM, CM 3, CM 3+, Zero and Zero W. Backwards compatibility for minor revisions isn’t guaranteed until v1.0.0.

Modules

gpio
Interface for the GPIO peripheral.
i2c
Interface for the I2C peripheral.
pwm
Interface for the PWM peripheral.
spi
Interface for the main and auxiliary SPI peripherals.
system
Raspberry Pi system-related tools.
uart
Interface for the UART peripherals and any USB to serial adapters.